@@ -16,12 +16,16 @@ class WhatsAppDefaultSource(SourceBase):
         frozen=True
     )
     agent_email: str = Field(default="default_settings@letschatty.com", frozen=True)
-    category: str = Field(default="default_sources", frozen=True)
+    category: str = Field(default="Primer contacto (nuevo chat) sin fuente de origen", frozen=True)
     source_checker: SourceCheckerType = Field(
         default=SourceCheckerType.FIRST_CONTACT,
         frozen=True
     )
 
+    @property
+    def default_category(self) -> str:
+        return "Primer contacto (nuevo chat) sin fuente de origen"
+
 
     @property
     def type(self) -> SourceType:
@@ -33,4 +37,3 @@ class WhatsAppDefaultSource(SourceBase):
 
     def __hash__(self) -> int:
         return hash(self.type)
-    
\ No newline at end of file
