@@ -23,6 +23,7 @@ class ChattyAssetPreview(TimestampValidationMixin, BaseModel):
     name: str
     company_id: StrObjectId = Field(frozen=True)
     created_at: datetime
+    deleted_at: Optional[datetime] = Field(default=None)
 
     model_config = ConfigDict(
         populate_by_name=True
@@ -34,7 +35,8 @@ class ChattyAssetPreview(TimestampValidationMixin, BaseModel):
             "_id": 1,
             "name": 1,
             "created_at": 1,
-            "company_id": 1
+            "company_id": 1,
+            "deleted_at": 1
         }
 
     @classmethod
@@ -44,7 +46,8 @@ class ChattyAssetPreview(TimestampValidationMixin, BaseModel):
             name=f"Not found {id}",
             company_id=company_id,
             created_at=datetime.now(tz=ZoneInfo("UTC")),
-            updated_at=datetime.now(tz=ZoneInfo("UTC"))
+            updated_at=datetime.now(tz=ZoneInfo("UTC")),
+            deleted_at=datetime.now(tz=ZoneInfo("UTC"))
         )
 
     @classmethod
@@ -58,7 +61,8 @@ class ChattyAssetPreview(TimestampValidationMixin, BaseModel):
             name=getattr(asset, "name", "no name"),
             company_id=asset.company_id,
             created_at=asset.created_at,
-            updated_at=asset.updated_at
+            updated_at=asset.updated_at,
+            deleted_at=asset.deleted_at
         )
 
 class ChattyAssetModel(TimestampValidationMixin, UpdateableMixin, BaseModel):
