@@ -24,7 +24,7 @@ from ...models.company.assets.ai_agents_v2.chatty_ai_mode import ChattyAIMode
 from ...models.company.assets.chat_assets import SaleAssignedToChat, AssignedAssetToChat, ChatAssetType, ContactPointAssignedToChat, ChattyAIAgentAssignedToChat
 from ...models.chat.scheduled_messages import ScheduledMessageStatus
 from ...models.utils.types.identifier import StrObjectId
-from ...models.utils.custom_exceptions.custom_exceptions import AssetAlreadyAssigned, NotFoundError, MessageAlreadyInChat, MetaErrorNotification, ChatAlreadyAssigned, AlreadyCompleted, ErrorToMantainSafety
+from ...models.utils.custom_exceptions.custom_exceptions import AssetAlreadyAssigned, MessageNotFoundError, NotFoundError, MessageAlreadyInChat, MetaErrorNotification, ChatAlreadyAssigned, AlreadyCompleted, ErrorToMantainSafety
 from ..factories.messages.central_notification_factory import CentralNotificationFactory
 from ...models.messages.chatty_messages.base.message_draft import MessageDraft
 from ...models.messages.chatty_messages.schema.chatty_content.content_central import CentralNotificationStatus
@@ -259,6 +259,10 @@ class ChatService:
         """
         Get the smart follow up state for the chat.
         """
+        logger.debug(f"Chat flow states: {chat.flow_states}")
+        for state in chat.flow_states:
+            logger.debug(f"type of state: {type(state)} | is instance of SmartFollowUpState: {isinstance(state, SmartFollowUpState)}")
+            logger.debug(f"state.is_smart_follow_up: {state.is_smart_follow_up}")
         return next((state for state in chat.flow_states if isinstance(state, SmartFollowUpState)), None)
 
     @staticmethod
@@ -423,7 +427,7 @@ class ChatService:
         message = chat.get_message_by_id(message_id)
         if message is None:
             # logger.warning(f"Message with id {message_id} not found in chat {chat.id}")
-            raise NotFoundError(message=f"Message with id {message_id} not found in chat {chat.id}")
+            raise MessageNotFoundError(message=f"Message with id {message_id} not found in chat {chat.id}")
 
         message.update_status(new_status=status, status_datetime=datetime.now())
         if message.subtype == MessageSubtype.TEMPLATE and status == Status.FAILED and error_details is not None:
