@@ -3,8 +3,8 @@ from typing import Dict, Type, TYPE_CHECKING
 import logging
 
 from .....models.analytics.sources import WhatsAppDefaultSource, TopicDefaultSource, PureAd, Source, TemplateSource, OtherSource
-from .....models.company.assets.ai_agents.chatty_ai_agent_config_for_automation import ChattyAIConfigForAutomation
-from .....models.company.assets.ai_agents.chatty_ai_agent_config_for_automation import ChattyAIMode
+from .....models.company.assets.ai_agents_v2.chatty_ai_agent_config_for_automation import ChattyAIConfigForAutomation
+from .....models.company.assets.ai_agents_v2.chatty_ai_agent_config_for_automation import ChattyAIMode
 from .....models.utils.types.identifier import StrObjectId
 from .....models.utils.types.source_types import SourceType, SourceCheckerType
 from .helpers import SourceFactoryHelpers
